unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, Pages, StdCtrls, ExtCtrls, Printers,
  {$IFNDEF VER100} ImgList, {$ENDIF} ComCtrls, ToolWin;

type
  TForm1 = class(TForm)
    PrinterSetupDialog1: TPrinterSetupDialog;
    ToolBar1: TToolBar;
    btnPreviewReport: TToolButton;
    ToolButton2: TToolButton;
    btnPrinterSetup: TToolButton;
    ToolButton3: TToolButton;
    btnClose: TToolButton;
    ImageList1: TImageList;
    Panel1: TPanel;
    Image1: TImage;
    Memo1: TMemo;
    procedure btnCloseClick(Sender: TObject);
    procedure btnPrinterSetupClick(Sender: TObject);
    procedure btnPreviewReportClick(Sender: TObject);
  private
    { Private declarations }
  public
  end;

var
  Form1: TForm1;

implementation

uses Preview;

{$R *.dfm}

procedure TForm1.btnPreviewReportClick(Sender: TObject);
var
  i, PageCenterX, YPos1, YPos2: integer;
  s: string;
  spellDict, SpellOut: TStringList;
begin
  spellDict := TStringList.Create;
  spellDict.LoadFromFile('words.txt');
  spellDict.Sorted := true;
  SpellOut := TStringList.Create;
  //try running this report on different sized paper and also
  //in landscape (eg try uncommenting the Orientation assignment below).
  PreviewForm := TPreviewForm.Create(self);
  with PreviewForm do
  try
    with Pages1 do
    begin
      //specifying a dictionary and a SpellCheckOutput TStrings instance
      //will force a spellcheck of the report ...
      SpellCheckDictionary := spellDict;
      SpellCheckOutput := SpellOut;

      //orientation must be set before calling BeginDoc...
      //Orientation := poLandscape;
      BeginDoc;
      PageCenterX := PaperSize.cx div 2;

      //OK, this is a weird report but it does demonstrate
      //many of the features of TPages ...

      //SETUP HEADERS, FOOTERS, COLUMN HEADERS ETC ...
      PageMargins := Rect(10,15,10,12);
      font.Name := 'Arial';
      font.Size := 10;
      font.Style := [fsBold];
      //nb: AddTextToHeaderAt() doesn't increment the YPos so the
      //following 2 strings will be printed on the same line with
      //one left aligned (the default) and the other right aligned.
      AddTextToHeaderAt('This is a quick TPages demo',10);
      TextAlign := taRight;
      AddTextToHeader(' 2003 - Angus Johnson');
      AddLineToHeader(false);

      AddLineToFooter(false);
      //note the use of the <<pagenumber>> placeholder.
      //(Pagenumber can be reset by assigning the VirtualPageNum property.)
      //AddTextToFooter('Page <<pagenumber>>'); //identical to ...
      AddTextToFooter('Page '+ PAGENUMBER);

      //setup some columns (this can be done anytime before using the columns)
      //(normally, I'd use constants for column boundaries but the following
      //enables the columns to be centered on any sized page - A4, A5, letter)
      NegsToParenthesesInCurrCols := true; //the accounting standard
      AddColumn(PageCenterX-60,PageCenterX-5,caLeft);
      AddColumn(PageCenterX,PageCenterX+25,caRight);
      AddColumn(PageCenterX+40,PageCenterX+60,caCurrency);
      font.Style := [fsBold,fsUnderline];

      AddColumnHeaders(['Item','Quantity','Cost']);
      font.Style := [];

    //PRINT SOME CENTERED TEXT ...
      NewLines(2);
      TextAlign := taCenter;
      DrawText('Click left mouse button to zoom in');
      DrawText('Click right mouse button to zoom out');
      NewLines(2);

    //SET TABSTOPS AND PRINT WITH SOME JUSTIFIED TEXT...
      TextAlign := taJustified;
      font.Style := [fsBold];
      font.Size := 20;
      DrawText('Tab Demo');
      font.Size := 10;
      font.Style := [];
      setTabstops([30]); //ie: 30mm,60mm,90mm,...
      DrawText(#9'*'#9'*'#9'*'#9'*');
      DrawText(#9'The asterisks show tabstops.'#9+
        'And now some more text justified and wrapping around to the next '+
        'line. Try changing the SetTabstops() command to 40mm too.');
      NewLines(3);

    //PRINT A BOX AROUND THE CURRENT PRINTER'S PAGE WIDTH AND HEIGHT ...
      YPos1 := CurrentYPos;    //get the current Y position
      NewLine;
      TextAlign := taCenter;
      with PaperSize do
        DrawText(format('Paper width = %dmm and height = %dmm',[cx, cy]));
      TextAlign := taJustified;
      NewLine;
      YPos2 := CurrentYPos;
      DrawBox(25,YPos1,PaperSize.cx -25,YPos2); //draw the box ...
      NewLines(3);

    //PRINT SOME WRAPPED & JUSTIFIED TEXT ...
      font.Style := [fsBold];
      font.Size := 20;
      DrawText('Chapter One');


      font.Size := 10;
      font.Style := [];
      NewLine;
      s := 'The quick brown fox jumps over the lazy dog. '+
           'Love the Lord your God with all your heart and mind and strength, '+
           'and love your neighbour as yourself. ';

      s := s + s;
      s := s + s + #10#10;
      s := s + s; //makes 4 paragraphs out of s
      s := s + s;
      DrawText(s);

   //PRINT SOME TEXT IN THE PREVIOUSLY DEFINED COLUMNS ...
      begingroup; //stop the group contents from being split across pages
      NewLine;
      font.Style := [fsBold];
      font.Size := 20;
      DrawText('Now a columned report ...');
      font.Size := 10;
      font.Style := [];
      NewLine;
      DrawTextAcrossCols(['Purchase Delphi','2','1,000.00']);
      //nb: see NegsToParenthesesInCurrCols boolean property ...
      DrawTextAcrossCols(['Credit for returned product','-1','-500.00']);
      DrawTextAcrossCols(['Purchase Kylix','1','500.00']);
      for i := 1 to 5 do
        DrawTextAcrossCols(['These are just extra lines ...']);
      DrawLinesInCurrencyCols(false);
      font.Style := [fsBold];
      DrawTextAcrossCols(['Total','','1,000.00','Ignored as no 4th column defined']);
      font.Style := [];
      DrawLinesInCurrencyCols(true);
      endGroup;

    //AN IMAGE, ARROW AND ANGLED TEXT ...
      NewLines(3);

      //DrawBmp() within a BeginGroup/EndGroup block makes the BMP invisible :(
      //This (I think) is because the bitmap is recorded onto the group
      //metafile canvas using StretchDIBits() which can't subsequently be
      //replayed onto the main metafile canvas.
      //BeginGroup;
      font.Style := [fsBold];
      font.Size := 20;
      DrawText('Printing an image, an arrow and some angled text ...');
      font.Size := 10;
      font.Style := [];
      NewLine;
      YPos1 := CurrentYPos;
      DrawBmp(rect(PageCenterX -16 , YPos1, PageCenterX+16, YPos1+32),
        image1.Picture.Bitmap);
      //Move the CurrentYPos to below the image and add an extra line space...
      CurrentYPos := YPos1 + 32;
      NewLine;
      //The following line is printed at an angle of 20...
      DrawAngledTextAt('Enter here!', PageCenterX-4, 20);
      //nb: Neither DrawAngledTextAt() nor DrawTextAt() increment the YPos

      //get some coordinates and then draw a red arrow ...
      YPos1 := CurrentYPos;
      NewLines(3);
      YPos2 := CurrentYPos;
      canvas.Pen.Color := clRed;
      //draw an arrow ...
      DrawArrow(Point(PageCenterX+ 22, YPos2),
        Point(PageCenterX+12, YPos1), 3, true);
      canvas.Pen.Color := clBlack;
      //endGroup;

    //OUTPUT SOME MORE WRAPPED & JUSTIFIED TEXT ...
      NewLine;
      font.Style := [fsBold];
      font.Size := 20;
      DrawText('Chapter Two');
      font.Size := 10;
      font.Style := [];
      NewLine;
      s := s;
      DrawText(s);
      NewLines(2);
      TextAlign := taCenter;
      font.Style := [fsBold];
      DrawText('The End!');
      enddoc;
    end;
    showmodal;

    //list the words (and their page numbers) not found in the dictionary ...
    memo1.Clear;
    if SpellOut.Count > 0 then
    begin
      memo1.Clear;
      Memo1.Lines.Add('');
      Memo1.Lines.Add('The following words weren''t found in the "words.txt" ' +
        'dictionary ...');
      Memo1.Lines.Add('');
      for i := 0 to SpellOut.Count -1 do
        Memo1.Lines.Add(
          format('%s on line %d', [SpellOut[i], integer(SpellOut.Objects[i])]));
      memo1.Visible := true;
    end;
  finally
    free; //PreviewForm
    spellDict.Free;
    SpellOut.Free;
  end;
end;
//------------------------------------------------------------------------------

procedure TForm1.btnPrinterSetupClick(Sender: TObject);
begin
  PrinterSetupDialog1.Execute;
end;
//------------------------------------------------------------------------------

procedure TForm1.btnCloseClick(Sender: TObject);
begin
  close;
end;
//------------------------------------------------------------------------------

end.
